@@ -1,5 +1,5 @@
-from Revolver import *
-from Jugador import *
+from ruletarusa.Revolver import *
+from ruletarusa.Jugador import *
 
 
 class Juego:
@@ -34,4 +34,4 @@ class Juego:
     def verificarNumeroJugadores(self, numero_jugadores):
         if numero_jugadores < 1 or numero_jugadores > 6:
             numero_jugadores = 6
-        return numero_jugadores
\ No newline at end of file
+        return numero_jugadores
